/** DTL/dtl.h
Copyright (c) 1990-1997, Inso Corporation
All Rights Reserved.
This work contains confidential trade secrets of Inso.  
Use, examination, copying, transfer and disclosure to others
are prohibited, except with the express written agreement of Inso.

This file is the public header file for the DynaText Libary.
**/


#ifndef DTL_HEADER
#define DTL_HEADER

/* $Id: dtl.h 1.142.1.2 1997/07/28 17:40:57 sgadepalli Exp $ */
/* $Log: dtl.h $
 * Revision 1.142.1.2  1997/07/28  17:40:57  sgadepalli
 * DynaText3.1.1: : Updating DTL_VERSION to 3.11 & DTL__LIBRARY_MINOR_VERSION to 1
 *
 * Revision 1.142.1.1  1997/07/13  16:31:13  sgadepalli
 * DynaText3.1.1:EBTei17091: Migrated fixes from 1.145 to 1.142
 *
 * Revision 1.142  1997/01/15  13:18:36  agk
 * Added DTLinit()
 *
 * Revision 1.141  1997/01/10  17:41:23  agk
 * added DTLgetIniFilePath(), DTLgetExePath() and DTLfree()
 *
 * Revision 1.140  1997/01/08  22:04:59  mdd
 * added new BOOK_ANNOTS_LOADED callback and some new flags for calls
 * to newBook, as well as two new variables for background annot loading
 * and exporting XML
 *
 * Revision 1.139  1997/01/08  15:42:48  agk
 * fixed to compile on Windows.
 * Note that OS_PASCAL is needed for all DTL functions.
 *
 * Revision 1.138  1996/12/13  20:16:21  cjh
 * Added DTL__APPLICATION_PRINT_PAGE_BREAK_CALLBACK.
 * Also added DTLflushStyleSheetCache, but ignore that for now.
 *
 * Revision 1.137  1996/10/29  15:20:14  mdd
 * changed the DTL variable definitions to lower case in order to
 * be consistent with SRTY
 *
 * Revision 1.136  1996/09/18  22:42:27  cjh
 * Added support for DTL__APP_PRIVATE_COLORMAP flag.
 *
 * Revision 1.135  1996/07/23  00:23:19  cjh
 * Implemented DTL__APPLICATION_SELECTION_COERCION_CALLBACK to allow
 * customers (SGI) to fold, spindle and mutilate the text that is
 * being pasted.
 *
 * Revision 1.134  1996/07/22  20:44:04  cjn
 * fix for EBTei12699.  Now error dialogs can be suppressed using
 * a DTLvariable.
 *
 * Revision 1.133  1996/07/22  19:53:47  cjh
 * Added DTL__SUPPRESS_CLEANUP_VARIABLE.
 * Also moved #include of <ebttypes.h> to prevent typedef Boolean
 * conflict w/ Xt for SIT customers.
 *
 * Revision 1.132  1996/07/19  21:34:28  mdd
 * added two variable constants
 *
 * Revision 1.131  1996/07/18  20:06:40  mdd
 * added DTLviewSetTitle
 *
 * Revision 1.130  1996/07/15  16:49:52  ewd
 * all char* args to DTLnewContextServer must be const
 *
 * Revision 1.129  1996/07/12  18:42:54  ewd
 * add DTL__SAVE_ALL_OPTIONS (= -1)
 * forces a save-to-disk of all option prefs.
 *
 * Revision 1.128  1996/06/10  16:46:47  mdd
 * removed extra param in DTLmultibyeMaxPerChar
 *
 * Revision 1.127  1996/06/09  17:32:21  mdd
 * added public INI file constants
 * /
 *
 * Revision 1.126  1996/06/07  15:09:35  cjh
 * Added DTL{toc}ViewReloadStyleSheet APIs. Woo!
 *
 * Revision 1.125  1996/06/06  16:33:18  ewd
 * add DTLunicodeLength(), DTLnativeMaxPerChar(), DTLmultibyteMaxPerChar()
 * also fix typo warning in previous checkin
 *
 * Revision 1.124  1996/06/06  13:32:18  agk
 * Updated the menu stuff to match all the new menus that
 * Glenn changed a while back.
 * Reviewed by CJN
 *
 * Revision 1.123  1996/05/07  15:36:06  cjh
 * Added new routine, DTLsetQueryFeedbackMode, to select the query mode
 * (single- or multiple-hit) for all open views.
 *
 * Revision 1.122  1996/05/06  14:24:14  cjn
 * add protection for mdepend.
 *
 * Revision 1.121  1996/05/01  21:55:20  glf
 * Added new application DTL flag: DTL__APP_NO_INITIAL_COLWIN to
 * allow window's apps to specify on the command line that dtext should
 * not create the initial collection window.  This has meaning on win32
 * only, as of now, because I think we must show the libwin on unix.
 *
 * Revision 1.120  1996/04/23  23:18:01  glf
 * Added new DTL view flag: DTL__DISABLE_SGML_EXPORT. This will be
 * forwarded to the Ftwin object, who will then disable all SGML
 * viewing and exporting (Copy SGML, Export SGML, Show Tags, etc.)
 *
 * Revision 1.119  1996/04/23  16:32:10  mdd
 * added compile time check for mutual exclusivity of DTL__<platform>_DEFS
 * define.
 *
 * Revision 1.118  1996/04/16  20:03:44  cjh
 * Added DTL__VIEW_MODE_SINGLE_HIT and _MULTIPLE_HITS.
 *
 * Revision 1.117  1996/04/10  17:38:38  cjh
 * EBTei09084 - enable DTLzoomView to zoom TOC, and added
 * DTLzoomTocView.
 *
 * Revision 1.116  1996/04/01  15:21:34  cjh
 * Added DTLgetFullTag and DTLwGetFullTag back - don't know
 * how they left, to be honest...
 *
 * Revision 1.115  1996/03/16  02:38:59  cjh
 * Number of fix-ups; ensured all functions are #ifdef use_prototypes,
 * removed spaces after function names to ensure plglink.awk can find
 * them, etc.
 *
 * Revision 1.114  1996/03/13  05:41:06  cjh
 * 	Implemented DTLaddwPropertyValueFunction - a new, much improved
 * 	interface for adding customs PVFs. It is wide, and it also uses
 * 	thread-safe techniques for retrieving the DtlContext and DtlBook
 * 	associated with the PVF evaluation (no more global DtlContextIds!),
 * 	adds a user_data and is generally just a Good Thing.
 *
 * Revision 1.113  1996/02/29  22:52:43  cjh
 * Braino - named a function twice
 *
 * Revision 1.112  1996/02/29  15:58:29  glf
 * Added needed DTL_EXPORT to declarations of new DTLNODE functions
 * (thanks to cmh!)
 *
 * Revision 1.111  1996/02/16  23:44:34  cjh
 * 	Added support for Viewer's chunky views; changed DTL flag
 * 	to DTL__CHUNKY_VIEW rather than DTL__X_CHUNKY_VIEW.
 *
 * Revision 1.110  1996/02/16  00:41:09  mdd
 * added some spaces so the plglink awk script would not choke
 *
 * Revision 1.109  1996/02/15  02:41:19  cjh
 * 	Added support for DTL__VIEW_PAINT_COMPLETE_CALLBACK for SGI.
 *
 * Revision 1.108  1996/02/15  02:12:21  cjh
 * Added prototypes for DTLNODExxx functions and associated enum.
 *
 * Revision 1.107  1996/02/14  23:02:16  dnc
 * added new coord transform routines for hotspot coords.
 *
 * Revision 1.106  1996/02/09  00:25:51  dnc
 * added routines for graphics coordinate transformations.
 *
 * Revision 1.105  1996/01/30  07:25:15  glf
 * Added a new item to the DtlGui struct: int nCmdShow. This allows a
 * SIT app via DTLnewContextFromGUI to control the appearance of the
 * desktop when first shown.  This was a long-standing defect.
 *
 * Revision 1.104  1996/01/19  19:58:27  cjh
 * Added DTL__PRINT_NODIALOG flag.
 *
 * Revision 1.103  1996/01/04  12:07:17  agk
 * added DTL_EXPORT to the rest of the functions
 * initialy I replaced all OS_EXPORT with DTL_EXPORT, but it
 * turned out that not all functions used OS_EXPORT
 * */

/** Includes
stdio: Standard input and output
X11/Intrinsic.h: X Definitions
**/

#define DTL_VERSION 	3.11

/* DynaText Toolkit Library version constants */
#define DTL__LIBRARY_MAJOR_VERSION    11
#define DTL__LIBRARY_MINOR_VERSION    1


#ifdef DTL__FULL_TOOLKIT
#ifndef DTL__SIT_DEFS
#define DTL__SIT_DEFS
#endif /* DTL__SIT_DEFS */
#endif /* DTL__FULL_TOOLKIT */

/*
Compile time check for DTL__<platform>_DEFS.
They are mutually exclusive, so cause an error
if two are defined.
*/
#ifdef DTL__X_DEFS
#ifdef DTL__WINDOWS_DEFS
#ifndef MDEPEND
#error
#endif /* MDEPEND */
#endif /* DTL__WINDOWS_DEFS */
#ifdef DTL__MAC_DEFS
#ifndef MDEPEND
#error
#endif /* MDEPEND */
#endif /* DTL__MAC_DEFS */
#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS
#ifdef DTL__MAC_DEFS
#ifndef MDEPEND
#error
#endif /* MDEPEND */
#endif /* DTL__MAC_DEFS */
#endif /* DTL__WINDOWS_DEFS */

#ifndef MDEPEND
#include <stdio.h>

#ifdef DTL__X_DEFS
#include <X11/Intrinsic.h>
#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS
#include <windows.h>
#endif /* DTL__WINDOWS_DEFS */

#endif /* MDEPEND */

#include <ebttypes.h>


/** Compiler Definitions
We quickly try to determine two characteristics about our
compiler:
1) Should we be using prototypes?
2) Can we use the void * datatype?
**/

#ifndef OS_HEADER

#ifndef DTL__NO_PROTOTYPES
#define use_prototypes
#define use_void
#endif /* DTL__NO_PROTOTYPES */


/** Standard Datatypes
Extract:
We create some standard datatypes here:
   Up: universal pointer
**/

#ifdef use_void
typedef void * Up;
#else
typedef char * Up;
#endif /* use_void */


/** OS Constants
**/

#if defined(__cplusplus) || defined(__STDC__)
#define OS_CONST const
#else
#define OS_CONST 
#endif

#if defined(DTL__WINDOWS_DEFS)
#define OS_EXPORT    __declspec(dllexport)
#define OS_IMPORT    __declspec(dllimport)
#else
#define OS_EXPORT
#define OS_IMPORT
#endif

#if defined(DTL__WINDOWS_DEFS)
#define OS_PASCAL 	__stdcall
#define OS_PASCALCB 	__stdcall
#elif defined(DTL__MAC_DEFS)
#define OS_PASCAL 	pascal
#define OS_PASCALCB 	CALLBACK
#else
#define OS_PASCAL 
#define OS_PASCALCB 
#endif

#define OS_CDECL 	
#define OS_CDECLCB 

#endif /* OS_HEADER */

/***************************************************************/
/* Plugin users must define DTL__PLUGIN before including DTL.H */
/***************************************************************/
#ifdef DTL__PLUGIN

#define DTL_EXPORT

#else

#ifdef DTL__WINDOWS_DLL
#define DTL_EXPORT OS_EXPORT
#else
#define DTL_EXPORT OS_IMPORT
#endif

#endif
/***************************************************************/


/** More Standard Datatypes
DTL__STRING_LENGTH: length of some API strings.  
DTL__HUGE_LENGTH: huge string length.
**/


#define DTL__STRING_LENGTH	256
#define DTL__HUGE_LENGTH	1024



/** Application Return Codes 
Doc:
   1) An enumeration of function return error codes.
   2) An enumeration of regular return codes.
**/

enum {
   /*** application ***/
   DTL__ERROR = -1,
   DTL__SUCCESS = 0,
   DTL__INITIALIZATION_ERROR,
   DTL__GRAPHICS_ERROR,
   DTL__BAD_WINDOW_ERROR,
   DTL__MEMORY_ERROR,

   /*** book ***/
   DTL__AUTHORIZATION_ERROR,
   DTL__BOOK_READING_ERROR,
   DTL__BOOK_ALREADY_OPEN_ERROR,
   DTL__INDEX_READING_ERROR,

   /*** view ***/
   DTL__ELEMENT_ID_ERROR,
   DTL__STYLESHEET_ERROR,

   /*** query ***/
   DTL__STOP_LIST_ERROR,
   DTL__QUERY_ERROR,
   DTL__STOP_LIST_NO_MATCH_ERROR,

   /*** other ***/
   DTL__NO_MATCH_ERROR,

   /*** collection window ***/
   DTL__OVERFLOW_ERROR,

   /*** API misusage ***/
   DTL__BAD_ARGUMENTS,
   DTL__MENU_ITEM_NOT_CHECKABLE
};

enum {
   DTL__SEQUENCE_RUNNING,
   DTL__SEQUENCE_FINISHED
};

/** Dtl Callback Return Values
DTL__CALLBACK_RETURN_DISABLE:
   disable item (grey it out)
DTL__CALLBACK_RETURN_REMOVE:
   remove item (get rid of it altogether)
DTL__CALLBACK_RETURN_SHOW:
   show item, keep item as it was
**/

enum {
   DTL__CALLBACK_RETURN_DISABLE,
   DTL__CALLBACK_RETURN_REMOVE,
   DTL__CALLBACK_RETURN_SHOW
};


/** Dtl Options
Dtl Options: These can be passed to DTLsetOption() and DTLgetOption().
             See DTLsetOption() for further explanation.
**/

#define DTL__SAVE_ALL_OPTIONS -1
enum {
   DTL__PRINT_FILE_OPTION = 0,
   DTL__QUERY_FEEDBACK_OPTION,
   DTL__EXACT_WITH_ACCENT_OPTION,
   DTL__EXACT_WITHOUT_ACCENT_OPTION,
   DTL__COPY_MODE_OPTION,
   DTL__SPOOLER_OPTION,
   DTL__HELP_BOOK_NAME_OPTION,
   DTL__NUMBER_OPTIONS
};


/** Dtl Variables
Dtl Variable: These are some standard values that can be used with
              DTLsetVariable() and DTLgetVariable(). See DTLsetVariable()
              for further explanation.
**/

#define DTL__DATA_DIR_VARIABLE                "data_dir"
#define DTL__USER_CATALOGS_VARIABLE           "user_catalogs"
#define DTL__SORT_COLLS_VARIABLE              "sort_colls"
#define DTL__CONFIG_FILE_VARIABLE             "config_file"
#define DTL__INLINE_CACHE_VARIABLE            "inline_cache"
#define DTL__COLL_CACHE_VARIABLE              "coll_cache"
#define DTL__LIBRARY_PATH_VARIABLE            "library_path"
#define DTL__REGISTRY_VARIABLE                "registry"
#define DTL__SUPPRESS_CLEANUP_VARIABLE        "suppress_cleanup"
#define DTL__SUPPRESS_ERROR_DIALOG_VARIABLE   "suppress_error_dialog"
#define DTL__BACKGROUND_ANNOTATION_VARIABLE   "background_annots"
#define DTL__EXPORT_XML_VARIABLE              "export_xml"

/** Application Types
Doc:
DTL__COPY...: 
   The different copy modes allow you to copy data
   from the browser and toc in all of the possible ways.

DTL__COPY_BASIC:
   Copies just the text.
DTL__COPY_SGML:
   Copies the sgml.
DTL__COPY_DERIVED:
   Copies the text as rendererd, with text-before/after and
   line breaks as you see them.
DTL__COPY_SGML_DERIVED:
   Same as COPY_DERIVED, but also copies sgml.
DTL__COPY_LOCATION:
   Copies an identifier for the current location to clipboard.
DTL__COPY_TITLES:
   Copies just the titles from TOC.
DTL__COPY_TITLES_SGML:
   Copies titles with the sgml.
**/

enum {
   DTL__COPY_BASIC = 0,
   DTL__COPY_SGML = 1,
   DTL__COPY_DERIVED = 2,
   DTL__COPY_SGML_DERIVED = 3,
   DTL__COPY_LOCATION = 4,
   DTL__COPY_TITLES = 5,
   DTL__COPY_TITLES_SGML = 6
};

/** Application Gui Datatypes
Doc:
   DtlGuiId: 
      Device independent method to pass around GUI constructs.
      This structure has different members for each platform:

UNIX:
   Display	*display	 X display 
   XtAppContext	context		 App Context 
   Widget	window		 window currently in discussion 

WINDOWS:
   HANDLE   hInstance;
   HANDLE   hPrevInstance;
   LPSTR    lpszCmdParam;
   int      nCmdShow;
   HWND     window;

 MAC:
   int			*display;
   int			context;
   WindowPtr	window;
**/

#ifdef DTL__X_DEFS
typedef struct _DtlGui {
   Display	*display;
   XtAppContext	context;
   Widget	window;
} DtlGui;
#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS
typedef struct _DtlGui {
   HANDLE   hInstance;
   HANDLE   hPrevInstance;
   LPSTR    lpszCmdParam;
   int      nCmdShow;
   HWND     window;
} DtlGui;
#endif /* DTL__WINDOWS_DEFS */

#ifdef DTL__MAC_DEFS
typedef struct _DtlGui {
   int			*display;
   int			context;
   WindowPtr	window;
} DtlGui;
#endif /* DTL__MAC_DEFS */

typedef struct _DtlGui	    *DtlGuiId;


/** Major Datatypes
DtlExrefId: is used as a handle to external scripts which have been created.
DtlContextId: application context
DtlViewId: view identifier of dtl view
DtlBookId: book identifier
DtlTocViewId: toc view identifier
DtlGraphicId: the graphic identifier
**/

typedef struct _DtlContext  *DtlContextId;
typedef struct _DtlExref * DtlExrefId;
typedef struct _DtlView  * DtlViewId;
typedef struct _DtlBook  *DtlBookId;
typedef struct _DtlTocView * DtlTocViewId;
typedef struct _DtlGraphic * DtlRasterId;
typedef struct _DtlGraphic * DtlGraphicId;
typedef struct _DtlColWin * DtlColWinId;
typedef struct _DtlColWinSeq * DtlColWinSeqId;
typedef struct _DtlBookSeq * DtlBookSeqId;
typedef struct _DtlViewSeq * DtlViewSeqId;
typedef struct _DtlTocViewSeq * DtlTocViewSeqId;
typedef struct _DtlMenuItem * DtlMenuItemId;


/** Plugin Datatypes
**/
typedef void *DtlPluginId;


/** DtlPluginInfo
System specific plugin info.
**/

typedef struct _DtlPluginInfo {
   DtlContextId contextId;
   Up user_data;
   /* windows-only stuff */
#ifdef DTL__WINDOWS_DEFS
   void *mdiContextId;
   void *dtlDdeMgrId;
   void *newContextAddress;   
   void *hAppInstance;
   void *hDtlInstance;
#endif /* DTL__WINDOWS_DEFS */

} DtlPluginInfo;
 
typedef struct _DtlPluginInfo *DtlPluginInfoId;

typedef struct _DtlPropertyValueInfo {
   DtlContextId contextId;
   DtlBookId bookId;
   unsigned long element;
} DtlPropertyValueInfo;

typedef struct _DtlPropertyValueInfo *DtlPropertyValueInfoId;

/** Major Callback Procs
DtlApplicationCallbackProc: callbacks from addApplicationCallback.
DtlScriptConstructProc: callback for constructing scripts
DtlScriptRefreshProc: callback for refreshing scripts
DtlScriptDestructProc: callback for destructing scripts
DtlAnnotScriptConstructProc: callback for constructing annotScripts
DtlAnnotScriptRefreshProc: callback for refreshing annotScripts
DtlAnnotScriptDestructProc: callback for destructing annotScripts
DtlInlineScriptConstructProc: callback for creating an inline object
DtlInlineScriptResizeProc: callback for resizing an inline object
DtlInlineScriptDestroyProc: callback for destroying an inline object

DtlBookCallbackProc: callbacks from addViewCallback
DtlViewCallbackProc: callbacks from addViewCallback
DtlTocViewCallbackProc: callbacks from addTocViewCallback
DtlTocViewGeneratorProc: callbacks from DTLgenerateTocSelections
DtlGraphicCallbackProc: callbacks from addGraphicCallback

DtlGraphicLoadProc: callback to create a graphic image

DtlPropertyValueProc: callback for prop value functions
DtlwPropertyValueProc: newer callback for prop value functions (Unicode)

DtlMenuItemProc: callback from a DTLmenu item
**/

#ifdef use_prototypes

typedef void (OS_PASCALCB *DtlApplicationCallbackProc)
  (DtlContextId, Up udata, 
   Up calldata1, Up calldata2, Up calldata3, Up calldata4);

typedef void (OS_PASCALCB *DtlBookCallbackProc)
   (DtlBookId, Up udata, Up cd1, Up cd2);

typedef void (OS_PASCALCB *DtlViewCallbackProc)
   (DtlViewId, Up udata, Up cd1, Up cd2,Up cd3);

typedef void (OS_PASCALCB *DtlTocViewCallbackProc)
   (DtlTocViewId, Up udata, Up cd1, Up cd2);

typedef int (OS_PASCALCB *DtlTocViewGeneratorProc)
   (DtlTocViewId, Up udata, unsigned long eid);

typedef void (OS_PASCALCB *DtlRasterCallbackProc)
   (DtlRasterId, Up udata, Up cd1, Up cd2, Up cd3, Up cd4);

typedef void (OS_PASCALCB *DtlGraphicCallbackProc)
   (DtlGraphicId, Up udata, Up cd1, Up cd2, Up cd3, Up cd4);

typedef int (OS_PASCALCB *DtlGraphicLoadProc)
   (Up data, char *filename, Up  pixmap, Up cmap, int *w, int *h, int *depth);

/*****************************************************************/

typedef Up (OS_PASCALCB *DtlScriptConstructProc)
   (DtlViewId, Up, DtlExrefId, unsigned long, char *);

typedef void (OS_PASCALCB *DtlScriptRefreshProc)
   (DtlViewId, Up, DtlExrefId, unsigned long);

typedef void (OS_PASCALCB *DtlScriptDestructProc)
   (DtlViewId, Up, DtlExrefId, unsigned long);

/*****************************************************************/

typedef int (OS_PASCALCB *DtlInlineScriptConstructProc)
   (DtlViewId, Up udata, char *parms, DtlGuiId parent,
    int width, DtlGuiId newchild, Up *retdata);

typedef void (OS_PASCALCB *DtlInlineScriptResizeProc)
   (DtlViewId, Up udata, char *parms,
    int width, DtlGuiId child, Up retdata);

typedef void (OS_PASCALCB *DtlInlineScriptDestroyProc)
   (DtlViewId, Up udata, DtlGuiId child, Up retdata);

/*****************************************************************/

typedef Up (OS_PASCALCB *DtlAnnotScriptConstructProc)
   (DtlBookId, Up, char *str,
    int, unsigned long, char *, char *, DtlViewId);

typedef void (OS_PASCALCB *DtlAnnotScriptRefreshProc)
                (DtlBookId, Up, unsigned long eid, 
		 int, char *);

typedef void (OS_PASCALCB *DtlAnnotScriptDestructProc)
                (DtlBookId, Up, unsigned long eid, int, char *);

typedef void (OS_PASCALCB *DtlPropertyValueProc)
   (char buf[], int maxbuf, int argc, char *argv[]);

typedef void (OS_PASCALCB *DtlwPropertyValueProc)
   (DtlPropertyValueInfoId id, Up user_data,
    UCSchar16 buf[], int maxbuf, int argc, UCSchar16 *argv[]);

typedef void (OS_PASCALCB *DtlMenuItemProc)
   (DtlContextId, DtlMenuItemId, Up user_data);

typedef void (OS_PASCALCB *DtlFreeProc) (void* buffer);

#else

typedef void (OS_PASCALCB *DtlApplicationCallbackProc)();
typedef void (OS_PASCALCB *DtlBookCallbackProc)();
typedef void (OS_PASCALCB *DtlViewCallbackProc)();
typedef void (OS_PASCALCB *DtlTocViewCallbackProc)();
typedef int (OS_PASCALCB *DtlTocViewGeneratorProc)();
typedef void (OS_PASCALCB *DtlRasterCallbackProc)();
typedef void (OS_PASCALCB *DtlGraphicCallbackProc)();
typedef int (OS_PASCALCB *DtlGraphicLoadProc)();
typedef Up (OS_PASCALCB *DtlScriptConstructProc)();
typedef void (OS_PASCALCB *DtlScriptRefreshProc)();
typedef void (OS_PASCALCB *DtlScriptDestructProc)();
typedef int (OS_PASCALCB *DtlInlineScriptConstructProc)();
typedef void (OS_PASCALCB *DtlInlineScriptResizeProc)();
typedef void (OS_PASCALCB *DtlInlineScriptDestroyProc)();
typedef Up (OS_PASCALCB *DtlAnnotScriptConstructProc)();
typedef void (OS_PASCALCB *DtlAnnotScriptRefreshProc)();
typedef void (OS_PASCALCB *DtlAnnotScriptDestructProc)();
typedef void (OS_PASCALCB *DtlPropertyValueProc)();
typedef void (OS_PASCALCB *DtlMenuItemProc)();
typedef void (OS_PASCALCB *DtlFreeProc) ();

#endif /* use prototypes */



/** Application Enumerations
Doc:
These are flags passed to DTLnewContext().
   DTL__ABOUT_BOX: Flag specifying that the about box ("splash box")
        should be shown at application startup.
   DTL__FRAME_WINDOW: Flag specifiying that an MDI frame 
        to parent the children in should be created. (ignored on UNIX systems).
   DTL__APP_NO_INITIAL_COLWIN: Flag specifying that the initial Collection
        Window that's typically shown should not be created. (ignored on
        UNIX systems).
   NOTE: All future application-level flags should start with __APP!   
**/

enum {
   DTL__ABOUT_BOX = (1L << 0),
   DTL__FRAME_WINDOW = (1L << 1),
   DTL__APP_NO_INITIAL_COLWIN = (1L << 2),
   DTL__APP_PRIVATE_COLORMAP = (1L << 3)
};


/** Application Callbacks
Doc: See DTLaddApplicationCallback for detailed description
     of each callback type.
**/

#define DTL__APPLICATION_ICON_CALLBACK			0
#define DTL__APPLICATION_QUIT_CALLBACK			1
#define DTL__APPLICATION_INPUT_CALLBACK			2
#define DTL__APPLICATION_ERROR_CALLBACK			3
#define DTL__APPLICATION_MENU_CALLBACK			4
#define DTL__APPLICATION_BOOK_OPEN_REQUEST_CALLBACK	5
#define DTL__APPLICATION_OPEN_REQUEST_CALLBACK		\
	DTL__APPLICATION_BOOK_OPEN_REQUEST_CALLBACK
#define DTL__APPLICATION_NOTE_DESTROY_CALLBACK		6
#define DTL__APPLICATION_ANNOT_OPEN_CALLBACK		7
#define DTL__APPLICATION_ANNOT_DELETE_CALLBACK		8
#define DTL__APPLICATION_VIEW_OPEN_CALLBACK		9
#define DTL__APPLICATION_TOC_VIEW_OPEN_CALLBACK 	10
#define DTL__APPLICATION_BOOK_OPEN_CALLBACK 		11
#define DTL__APPLICATION_SEARCH_CALLBACK 		12
#define DTL__APPLICATION_COLLECTION_SEARCH_CALLBACK	13
#define DTL__APPLICATION_LIBRARY_SECURITY_CALLBACK 	14
#define DTL__APPLICATION_BOOK_SECURITY_CALLBACK 	15
#define DTL__APPLICATION_GRAPHIC_OPEN_CALLBACK 		16
#define DTL__APPLICATION_COLWIN_OPEN_CALLBACK 		17
#define DTL__APPLICATION_COLWIN_OPEN_REQUEST_CALLBACK	18
#define DTL__APPLICATION_SELECTION_COERCION_CALLBACK    19
#define DTL__APPLICATION_PRINT_PAGE_BREAK_CALLBACK      20
#define DTL__NUMBER_APPLICATION_CALLBACKS               21



/** Print System Datatypes
We specify the datatypes associated with a the Print System:
   DtlPrintId: an identifier for a printing context.
   Print Options: 
      DTL__PRINT_GRAPHICS: should graphics be printed.
      DTL__PRINT_ANNOTS: should annotations be printed.
   
**/

enum {
   DTL__PRINT_GRAPHICS = (1L << 0),
   DTL__PRINT_ANNOTS = (1L << 1),
   DTL__PRINT_NODIALOG = (1L << 2)
};

typedef struct _DtlPrint * DtlPrintId;

/** Book Datatypes
We specify the datatypes associated with a DTL book:

   DTL__ROOT_ELEMENT: element id of the root of a book
   DTL__NULL_ELEMENT: element id signifying no element
   DTL__CDATA: cdata string
   DTL__SHOW_TOC: create a book with a toc
   DTL__SHOW_VIEW: create a book with a fulltext view
   DTL__SHOW_MULTIVIEW: create a book with a multiview fulltext/toc view
   DTL__ELEMENT_SEPARATOR: tag name separator

DTL__ACCESS_PUBLIC: public annotation access
DTL__ACCESS_PRIVATE: private annotation access

DtlAnnotStruct:
   This record structure holds all information about a given annotation.
      title: name of annotation
      annot_type: type of annotation, such as "Note", "Bookmark"
                  or what you pass to DTLaddAnnotScript().
      owner: owner of annotation
      access: access, DTL__ANNOT_ACCESS_PUBLIC or DTL__ANNOT_ACCESS_PRIVATE
      timestamp: time in universal time when annotation was created
      script: script to run to launch annot
      paramters: paramaters to send to script
**/


enum {
   DTL__ACCESS_PRIVATE = 0,
   DTL__ACCESS_PUBLIC,
   DTL__ACCESS_ALL
};

#define DTL__ROOT_ELEMENT	1L
#define DTL__NULL_ELEMENT	0L
#define DTL__CDATA		"#CDATA"
#define DTL__ELEMENT_SEPARATOR  ','

typedef struct _DtlAnnotStruct {
   char *title;
   char *annot_type;
   char *owner;
   char *script;
   char *parameters;
   long timestamp;
   int	access;
} DtlAnnotStruct;


/** DTL Window Type
For use in DTLmenu package, for now.
**/

typedef enum {
   DTL__WINDOW_TYPE_UNKNOWN = 0,
   DTL__WINDOW_TYPE_VIEW,
   DTL__WINDOW_TYPE_GRAPHIC,
   DTL__WINDOW_TYPE_COLWIN
}  DtlWindowType;

/** DTLmenu flags
Specifies info about a DtlMenuItem.

Example:
   (How to add a new checkable menuitem with the separator after to the view menu)
   
   DtlMenuItemFlags flags;                                           ****************
   flags=(DTL__MENU_ITEM_CHECKABLE | DTL__MENU_ITEM_SEPARATOR_AFTER) + DTL__VIEW_MENU;
                                                                     ****************
                                                                     
   (Note that the "+ DTL__VIEW_MENU" is new to Dynatext 3.0)
**/

enum {
   DTL__MENU_ITEM_DEFAULT = 0L,
   DTL__MENU_ITEM_CHECKABLE = ( 1L << 0 ),
   DTL__MENU_ITEM_SEPARATOR_BEFORE = ( 1L << 1 ),
   DTL__MENU_ITEM_SEPARATOR_AFTER = ( 1L << 2 ),

   /* --------------------------------- */
   /* --- Dynatext 3.0 new settings --- */
   /* --------------------------------- */
   DTL__FILE_MENU                      = (1 << 16),   /* "file" */
   DTL__EDIT_MENU                      = (2 << 16),   /* "edit" */
   DTL__SEARCH_MENU                    = (3 << 16),   /* "search" */
   DTL__BOOK_MENU                      = (4 << 16),   /* "book" */
   DTL__JOURNAL_MENU                   = (5 << 16),   /* "journal" */
   DTL__VIEW_MENU                      = (6 << 16),   /* "view" */
   
   /* Windows & Mac only... */
   DTL__WINDOW_MENU                    = (7 << 16), 
   
   DTL__HELP_MENU                      = (8 << 16),   /* "help" */
  
   /* Windows only... (reserved 9 & 10) */
   
   /* Unix only...    (reserved 11 & 12) */
   DTL__OPTIONS_MENU                   = (11 << 16),   /* "options" */
   
   /* Mac only...    (reserved 13 & 14) */
   
   /* All platforms. (reserved 15) */
   
   /* --------------------------------- */
   /* ----------- Submenus ------------ */
   /* --------------------------------- */
   
   DTL__VIEW_TOC_MENU                  = (16 << 16),   /* "toc-view" */
   DTL__VIEW_CONTENT_MENU              = (17 << 16),   /* "ft-view" */
   DTL__VIEW_ZOOM_MENU                 = (18 << 16),   /* "zoom-main" */
   DTL__VIEW_EXPAND_TOC_TO_MENU        = (19 << 16)    /* "expand-toc" */
};
typedef long DtlMenuItemFlags;


/** Book Callbacks
See DTLaddBookCallback for more information on each callback type.
**/

enum {
   DTL__BOOK_DESTROY_CALLBACK,
   DTL__BOOK_TOC_CALLBACK,
   DTL__BOOK_ANNOTS_LOADED_CALLBACK,
   DTL__NUMBER_BOOK_CALLBACKS
};


/** Book Creation Flags
DTL__SHOW_TOC: show a toc when book is created.
DTL__SHOW_VIEW: show fulltext view when book is created.
DTL__SHOW_MULTIVIEW: show both when view is created.
DTL__BACKGROUND_ANNOTS: load annotations in background.
DTL__DISABLE_ANNOTS: completely disable annotations.
**/

enum {
   DTL__SHOW_TOC          = (1L << 0),
   DTL__SHOW_VIEW         = (1L << 1),
   DTL__BACKGROUND_ANNOTS = (1L << 2),
   DTL__DISABLE_ANNOTS    = (1L << 3)
};

#define DTL__SHOW_MULTIVIEW  (DTL__SHOW_TOC | DTL__SHOW_VIEW)

/** Toc View Datatypes
DTL__TOC_MODE_NORMAL: normal action in toc, drives fulltext view.
DTL__TOC_MODE_SELECT: select items for actions like printing,
                      does not drive fulltext view.
**/

enum {
   DTL__TOC_MODE_NORMAL,
   DTL__TOC_MODE_SELECT
};

/** Toc View Modes
  DTL__TOCVIEW_SORT - sort toc entries
  DTL__TOCVIEW_ELIDE - elide toc (remove certain Toc entries)
**/

enum {
   DTL__TOCVIEW_SORT,
   DTL__TOCVIEW_ELIDE
};

/** Toc View Sorting Mode methods
  DTL__TOCVIEW_SORT_HITS - Sort entries with most query hits first
  DTL__TOCVIEW_SORT_NONE - Do not sort entries.
**/

enum {
   DTL__TOCVIEW_SORT_HITS,
   DTL__TOCVIEW_SORT_NONE
};

/** Toc View Elision Mode methods
  DTL__TOCVIEW_ELIDE_HITS - Remove TOC entries with no query hits
  DTL__TOCVIEW_ELIDE_NONE - Do not remove any TOC entries.
**/

enum {
   DTL__TOCVIEW_ELIDE_HITS,
   DTL__TOCVIEW_ELIDE_NONE
};

/** Toc View Callbacks
DTL__TOC_VIEW_DESTROY_CALLBACK: 
DTL__TOC_VIEW_INPUT_CALLBACK: 
See DTLaddTocViewCallback() for further information.
**/

enum {
   DTL__TOC_VIEW_DESTROY_CALLBACK,
   DTL__TOC_VIEW_INPUT_CALLBACK,
   DTL__TOC_VIEW_RESIZE_CALLBACK,
   DTL__NUMBER_TOC_VIEW_CALLBACKS
};


/** Query Datatypes
We specify the datatypes associated with a DTL Query:
   DtlQueryId: id for a query.

   DTL__FULL_FEEDBACK: provide number of occurences in toc.
   DTL__RELEVANCE_FEEDBACK: provide relevance (log) function in toc.
   DTL__BINARY_FEEDBACK: provide yes/no in toc.

   DTL__QUERY_MERGE_INSIDE: merge query 1 inside query 2 in call
                            to DTLmergeQueries().
   DTL__QUERY_MERGE_NOT_INSIDE: merge query 1 not inside query 2 in
                                call to DTLmergeQueries().
   DTL__QUERY_MERGE_CONTAINING: merge query 1 containing query 2.
   DTL__QUERY_MERGE_NOT_CONTAINING: merge query 1 not containing query 2.
   DTL__QUERY_MERGE_OR: merge query 1 or query 2.
   DTL__QUERY_MERGE_AND: merge query 1 and query 2.
**/

typedef struct _DtlQuery * DtlQueryId;

enum {
   DTL__FULL_FEEDBACK,
   DTL__RELEVANCE_FEEDBACK,
   DTL__BINARY_FEEDBACK
};

enum {
   DTL__QUERY_MERGE_INSIDE,
   DTL__QUERY_MERGE_NOT_INSIDE,
   DTL__QUERY_MERGE_CONTAINING,
   DTL__QUERY_MERGE_NOT_CONTAINING,
   DTL__QUERY_MERGE_OR,
   DTL__QUERY_MERGE_AND
};



/** Lib Query Datatypes
We specify the datatypes associated with a DTL Library Level Query:
   DtlLibQueryId: id for a query.
   DTL__LIB_QUERY_INCLUDE_CONTEXT: does library query with inside allowed.
   DTL__LIB_QUERY_ROBUST_SEARCH: does a full query even if it involves
                                 more time to open actualy book indices.
**/

enum {
   DTL__LIB_QUERY_INCLUDE_CONTEXT = (1L << 0),
   DTL__LIB_QUERY_ROBUST_SEARCH = (1L << 1)
};

typedef struct _DtlLibQuery * DtlLibQueryId;


/** Hist Datatypes
We specify the datatypes associated with a DTL Hist:
   DtlHistoryId: id for a history.
**/

typedef struct _DtlHistory * DtlHistoryId;



/** DtlView Enums
   DTL__SHOW_HEADER: specifies that a view should have an EBT header.
   DTL__SHOW_LOGO: specifies that a view should have an EBT logo.
                   must have header to have a logo. (phasing out)
   DTL__SHOW_LOOKUP: shows the search gadgets		  
   DTL__MULTI_VIEW: specifies that a view should have both a TOC and
                    a fulltext view.
   DTL__STANDALONE_VIEW: specifies that book is closed when this
                         is the last view to close and there is no toc.
   DTL__GLOSSARY_VIEW: specifies that view is closed when focus is lost
   DTL__REVELATORY_VIEW: view is a revelatory, and we should 
                         unhide the root element from the style sheet.
   DTL__HSCROLL_VIEW: view is a table, try to horizontal scroll.
   DTL__KEEP_STACK: specifies that a view should keep a history stack.	
                    if DTL__SHOW_HEADER is on, this is automatic.
   DTL__DISABLE_SGML_EXPORT: specifies that all SGML related items should
                    be disabled in the multi-view: Copy SGML, Show Tags,
                    Exporting of SGML titles or content.
     (Windows Only option)
   DTL__HIDE_TABS: Do not show the Stylesheet Tabs (Default is ON)

**/


enum {
   DTL__SHOW_HEADER = (1L << 0),
   DTL__SHOW_LOGO = (1L << 1),   /* PHASING OUT AFTER 2.0 */
   DTL__KEEP_STACK = (1L << 2),
   DTL__STANDALONE_VIEW = (1L << 3),
   DTL__GLOSSARY_VIEW = (1L << 4),
   DTL__MULTI_VIEW = (1L << 5),
   DTL__SHOW_LOOKUP = (1L << 6),
   DTL__REVELATORY_VIEW = (1L << 7),
   DTL__HSCROLL_VIEW = (1L << 8),
   DTL__CHUNKY_VIEW = (1L << 9),
   DTL__DISABLE_SGML_EXPORT = (1L << 10),
   DTL__HIDE_TABS = (1L << 11)
      /* private starts at 12 */
};

/** Dtl View Modes
   DTL__VIEW_MODE_NORMAL: normal view and selecting
   DTL__VIEW_MODE_NO_SELECT: turn off user selection
   DTL__VIEW_MODE_SINGLE_HIT: enable single-hit query feedback
   DTL__VIEW_MODE_MULTIPLE_HITS: enable multiple-hit query feedback
**/

enum {
   DTL__VIEW_MODE_NORMAL,
   DTL__VIEW_MODE_NO_SELECT,
   DTL__VIEW_MODE_SINGLE_HIT,
   DTL__VIEW_MODE_MULTIPLE_HITS
};

/** DtlView Callbacks
See DTLaddViewCallback() for further explanation.
**/

enum {
   DTL__VIEW_DESTROY_CALLBACK,
   DTL__VIEW_SCROLL_CALLBACK,
   DTL__VIEW_RESIZE_CALLBACK,
	DTL__VIEW_HSCROLL_CALLBACK,
	DTL__VIEW_SELECTION_CALLBACK,
   DTL__VIEW_PAINT_COMPLETE_CALLBACK,
   DTL__NUMBER_VIEW_CALLBACKS
};


/** DtlView Datatypes
 The DtlViewComponent Types: Allows caller to access platform-
 specific handle to the pieces of a DtlViewId. See
 DTLinqViewComponent() for further explanation.

   DTL__VIEW_CONTAINER_COMP: Top-level window handle (to the view itself)
   DTL__VIEW_SPLITPANE_COMP: Handle to splitpane (contains Fulltext and
     Toc).
   DTL__VIEW_SRCHPANEL_COMP: Handle to search panel.
   DTL__VIEW_TOC_COMP: Handle to TOC pane in splitpane. 
   DTL__VIEW_FULLTEXT_COMP: Handle to Fulltext pane in splitpane.
   DTL__VIEW_MENUBAR_COMP: Handle to menubar of window (UNIX only).

 The DtlViewLayout structure holds information about a given view's
 layout.  For each field, an "ignore" value can be set.  This allows
 you selectively change attributes of a view, while leaving other
 attributes unchanged. Fields:
 
 .tocPosition: the position of the TOC in the splitpane portion of
     the DtlView.  If the DltView has no TOC, this value is ignored.
     This value implicitly controls whether the splitbar is horizatal or
     vertical. When the TOC is positioned TOP or BOTTOM, the splitbar appears
     horizontal; when positioned LEFT or RIGHT, the splitbar appears
     vertical.
     > NOTE: On UNIX, only TOP and LEFT are supported. 
 .srchPanel: whether or not the search panel is shown.  If the view has
     not yet been mapped, this value will take effect when mapped.  If
     the view is mapped, the search panel visibility will immediately toggle. 
 .barType: thickness of the splitbar in View's splitpane.
     > NOTE: This field is ignored on UNIX (& Mac?)
 .barPosition: position of splitbar in the View's splitpane, based on
     the percent size of the TOC.  Values range from 0 to 100.   
     * 0 means position the splitbar all the way to one side, showing
       only the Fulltext view.  The user can manually slide the split
       bar to reveal the TOC.
     * 100 means position the splitbar all the way to one side, showing
       only the TOC.
     * DTL__VIEW_BARPOS_IGNORE means leave the current splitbar position.
     * DTL__VIEW_BARPOS_DEFAULT means allow DTL to place the splitbar.
       The default division is approx. 40% toc to 60% fulltext.
**/

typedef enum {
   DTL__VIEW_CONTAINER_COMP,   /* top-level window handle */
   DTL__VIEW_SPLITPANE_COMP,   /* handle to splitpane */
   DTL__VIEW_SRCHPANEL_COMP,   /* handle to search panel */
   DTL__VIEW_TOC_COMP,         /* handle to toc portion of splitpane */
   DTL__VIEW_FULLTEXT_COMP,    /* handle to fulltext portion of splitpane */
   DTL__VIEW_MENUBAR_COMP      /* handle to menubar (UNIX only) */
} DtlViewComponent;

typedef enum {
  DTL__VIEW_TOCPOS_IGNORE,      /* leave currrent setting; use default */
  DTL__VIEW_TOCPOS_TOP,         /* place toc on top (horiz splitbar)  */ 
  DTL__VIEW_TOCPOS_BOTTOM,      /* place toc on bottom (horiz splitbar) */
  DTL__VIEW_TOCPOS_LEFT,        /* place toc on left (vert splitbar)  */ 
  DTL__VIEW_TOCPOS_RIGHT        /* place toc on right (vert splitbar) */
} DtlViewTocPos;

typedef enum {
  DTL__VIEW_SRCHPANEL_IGNORE,   /* leave current setting; use default */
  DTL__VIEW_SRCHPANEL_SHOW,     /* show the search panel */
  DTL__VIEW_SRCHPANEL_HIDE      /* hide the search panel */
} DtlSrchPanelState;

typedef enum {
  DTL__VIEW_SPLITBAR_IGNORE,    /* leave current setting; use default */
  DTL__VIEW_SPLITBAR_NORMAL,    /* normal (thin) splitbar */
  DTL__VIEW_SPLITBAR_WIDE       /* thick splitbar */
} DtlViewSplitbarType;

#define DTL__VIEW_BARPOS_IGNORE    -1 /* leave current setting */
#define DTL__VIEW_BARPOS_DEFAULT   -2 /* use DTL default; split window 
                                         approx: TOC (40%) : Fulltext (60%) */

typedef struct _DtlViewLayout { 
   DtlViewTocPos       tocPosition;
   DtlSrchPanelState   srchPanel; 
   DtlViewSplitbarType barType;
   int                 barPosition;
} DtlViewLayout;


/** DtlElemGeom
DtlElemGeom: Structure used to pass around element geometries.
**/

typedef struct _DtlElemGeom {
   unsigned long eid;
   int	x, y, w, h;
} DtlElemGeom;


/** Graphic Callbacks
See DTLaddGraphicCallback for further information.
**/

enum {
   DTL__GRAPHIC_DESTROY_CALLBACK,
   DTL__GRAPHIC_BUTTON_PRESS_CALLBACK,
   DTL__GRAPHIC_REGION_CALLBACK,
   DTL__NUMBER_GRAPHIC_CALLBACKS
};


/** Graphic Formats
DTL__GRAPHIC_FORMAT_RASTER: A raster graphic.
DTL__GRAPHIC_FORMAT_CGM: A cgm graphic.
DTL__GRAPHIC_FORMAT_GRAPHIC: A cgm OR raster graphic.
DTL__GRAPHIC_FORMAT_VIDEO: Unsupported at this time.
**/

enum {
   DTL__GRAPHIC_FORMAT_RASTER,
   DTL__GRAPHIC_FORMAT_CGM,
   DTL__GRAPHIC_FORMAT_VIDEO,
	DTL__GRAPHIC_FORMAT_GRAPHIC
};


/** Raster Datatypes
Rasters are just here for backward compatibility.
Will be replaced by graphics post 2.0.
**/

enum {
   DTL__RASTER_DESTROY_CALLBACK = DTL__GRAPHIC_DESTROY_CALLBACK,
   DTL__RASTER_BUTTON_PRESS_CALLBACK = DTL__GRAPHIC_BUTTON_PRESS_CALLBACK,
   DTL__NUMBER_RASTER_CALLBACKS
};


/** Database Node Info Types
For determining the type of information contained in a node.
**/
#define DTL__EMPTY_NODE  (DTL__ERROR + 1)
#define DTL__NORMAL_NODE (DTL__ERROR + 2)
#define DTL__NDATA_NODE  (DTL__ERROR + 3)
#define DTL__SDATA_NODE  (DTL__ERROR + 4)
#define DTL__CDATA_NODE  (DTL__ERROR + 5)

/** C++ Support and C Support
**/

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/** Application Context Prototypes
We specify the application context functions available.
**/

/*** amain.cc ***/
extern 
DTL_EXPORT
void
OS_PASCAL
DTLhook(
#ifdef use_prototypes
DtlContextId	id,
long	key,
long	op
#endif
);

/*** Main Routines ***/
extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLnewContext(
#ifdef use_prototypes
int	*argc,
char	*argv[],
OS_CONST char 	*data_dir, 
OS_CONST char	*x_dir,
OS_CONST char	*private_dir,
OS_CONST char	*public_dir,
OS_CONST char	*auth_service,
long 	flags
#endif
);

extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLnewContextFromGUI(
#ifdef use_prototypes
OS_CONST char	*name,
OS_CONST char	*classname,
OS_CONST char 	*data_dir, 
OS_CONST char	*private_dir,
OS_CONST char	*public_dir,
OS_CONST char	*auth_service,
long 	flags,
DtlGuiId	gui
#endif
);

extern
DTL_EXPORT
DtlGuiId	
OS_PASCAL
DTLinqGUI(
#ifdef use_prototypes
DtlContextId	id
#endif
);

/* PHASING OUT AFTER 2.0 */
#ifdef DTL__X_DEFS
extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLnewContextFromX(
#ifdef use_prototypes
char	*name,
char	*classname,
char 	*data_dir, 
char	*private_dir,
char	*public_dir,
char	*auth_service,
long 	flags,
Display	*display,
XtAppContext	context
#endif
);

#endif /* DTL__X_DEFS */



#ifdef DTL__WINDOWS_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLnewContextFromWindows(
#ifdef use_prototypes
HANDLE 	hInstance,
HANDLE 	hPrevInstance,
LPSTR 	lpszCmdParam,
int 	nCmdShow,
char 	*data_dir, 
char	*private_dir,
char	*public_dir,
char	*auth_service,
long 	flags		
#endif
);
#endif /* DTL__WINDOWS_DEFS */


#ifdef DTL__SIT_DEFS

extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLnewContextServer(
#ifdef use_prototypes
OS_CONST char 	*data_dir, 
OS_CONST char	*private_dir,
OS_CONST char	*public_dir,
OS_CONST char	*auth_service,
long 	flags
#endif
);

#endif /* DTL__SIT_DEFS */

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqVersion(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLcheckLibraryVersion(
#ifdef use_prototypes
int  major_version,
int  minor_version
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqLibraryVersion(
#ifdef use_prototypes
int  *major_version,
int  *minor_version
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyContext(
#ifdef use_prototypes
DtlContextId	id
#endif
);


/*** Error Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetError(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern 
DTL_EXPORT
void
OS_CDECL
DTLerrorBox(
#ifdef use_prototypes
DtlContextId id,
int eid,
...
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetErrCallback(
#ifdef use_prototypes
DtlContextId id,
DtlApplicationCallbackProc callback,
Up user_data
#endif
);


/*** Collection Window Routines ***/

extern 
DTL_EXPORT
DtlColWinId
OS_PASCAL
DTLinqDefaultColWin(
#ifdef use_prototypes
	DtlContextId contextId
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLupdateColWin(
#ifdef use_prototypes
	DtlColWinId	colWinId, 
	char *		collection
#endif
);


extern
DTL_EXPORT
int
OS_PASCAL
DTLinqActiveCols(
#ifdef use_prototypes
	DtlColWinId colWinId, 
	char *		buf,
	int 			buf_size,
	int *			bytes_written,
	int *			num_collections
#endif
);


extern
DTL_EXPORT
int
OS_PASCAL
DTLinqCurrentBook(
#ifdef use_prototypes
DtlColWinId 	colWinId, 
	char *		pathbuf,
	int 			pathbuf_size,
	int *			pathbuf_bytes_written,
	char *		aliasbuf,
	int 			aliasbuf_size,
	int *			aliasbuf_bytes_written
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqColAlias(
#ifdef use_prototypes
DtlColWinId 	colWinId, 
	char *		collection,
	char *		buf, 
	int			buf_size,
	int *			bytes_written
#endif
);


extern
DTL_EXPORT
int
OS_PASCAL
DTLperformColWinQuery(
#ifdef use_prototypes
   DtlColWinId cwid,
   const char *queryString
#endif
);



/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			  Iterator Functions
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/

/*
 * colwin iterator
 */ 

extern
DTL_EXPORT
DtlColWinSeqId
OS_PASCAL
DTLstartColWinSequence(
#ifdef use_prototypes
	DtlContextId	contextId
#endif
);


extern 
DTL_EXPORT
DtlColWinId
OS_PASCAL
DTLnextColWinSequence(
#ifdef use_prototypes
	DtlColWinSeqId colWinSeqId
#endif
);


extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyColWinSequence(
#ifdef use_prototypes
	DtlColWinSeqId colWinSeqId
#endif
);

/*
 * book iterator
 */ 

extern 
DTL_EXPORT
DtlBookSeqId
OS_PASCAL
DTLstartBookSequence(
#ifdef use_prototypes
	DtlContextId	contextId
#endif
);


extern 
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLnextBookSequence(
#ifdef use_prototypes
	DtlBookSeqId bookSeqId
#endif
);


extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyBookSequence(
#ifdef use_prototypes
	DtlBookSeqId bookSeqId
#endif
);

/*
 * view iterator
 */ 

extern 
DTL_EXPORT
DtlViewSeqId
OS_PASCAL
DTLstartViewSequence(
#ifdef use_prototypes
	DtlBookId bookId
#endif
);


extern 
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnextViewSequence(
#ifdef use_prototypes
	DtlViewSeqId viewSeqId
#endif
);


extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyViewSequence(
#ifdef use_prototypes
	DtlViewSeqId viewSeqId
#endif
);

/*
 * tocView iterator
 */ 

extern 
DTL_EXPORT
DtlTocViewSeqId
OS_PASCAL
DTLstartTocViewSequence(
#ifdef use_prototypes
	DtlBookId bookId
#endif
);


extern 
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLnextTocViewSequence(
#ifdef use_prototypes
	DtlTocViewSeqId tocViewSeqId
#endif
);


extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyTocViewSequence(
#ifdef use_prototypes
	DtlTocViewSeqId tocViewSeqId
#endif
);



/*** Option Routines ***/

extern
DTL_EXPORT
void
OS_PASCAL
DTLsetOption(
#ifdef use_prototypes
DtlContextId	id,
int	option,
Up	value
#endif
);

extern
DTL_EXPORT
Up
OS_PASCAL
DTLgetOption(
#ifdef use_prototypes
DtlContextId	id,
int	option
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLreadOption(
#ifdef use_prototypes
DtlContextId id, 
char *fname, 
char *var,
char *name, 
char buf[], 
int maxbuf
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLsetVariable(
#ifdef use_prototypes
OS_CONST char *variable, 
OS_CONST char *value
#endif
);

extern
DTL_EXPORT
char*
OS_PASCAL
DTLgetVariable(
#ifdef use_prototypes
OS_CONST char *variable
#endif
);


/*** Interface Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateMainWindow(
#ifdef use_prototypes
DtlContextId	id,
char	*name,
char	*title,
char	*book_dbases,
DtlApplicationCallbackProc	quit_callback,
Up	user_data
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLsetBookDatabases(
#ifdef use_prototypes
DtlContextId	id,
char	*book_dbases
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqBookDatabases(
#ifdef use_prototypes
DtlContextId	contextId
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLsetBookKeys(
#ifdef use_prototypes
DtlContextId    id,
char    *collection_keys,
char    *book_keys
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmapMainWindow(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapMainWindow(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLshowHistWindow(
#ifdef use_prototypes
DtlContextId	id,
int	open
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLshowErrorWindow(
#ifdef use_prototypes
DtlContextId id
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLlookupString(
#ifdef use_prototypes
DtlContextId	id,
int	num,
int	cache
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLmainLoop(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLeventSuppress(
#ifdef use_prototypes
   DtlContextId id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLeventEnable(
#ifdef use_prototypes
   DtlContextId id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLnextEvents(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLstartWait(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLendWait(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLbeep(
#ifdef use_prototypes
DtlContextId	id,
int	vol,
int	num
#endif
);


#ifdef DTL__SIT_DEFS


/*** Script Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddScript(
#ifdef use_prototypes
DtlContextId	id,
char	*script_name,
DtlScriptConstructProc		construct,
DtlScriptRefreshProc		refresh,
DtlScriptDestructProc		destruct,
Up	user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddAnnotScript(
#ifdef use_prototypes
DtlContextId	id,
char	*script_name,
DtlAnnotScriptConstructProc		construct,
DtlAnnotScriptRefreshProc		refresh,
DtlAnnotScriptDestructProc		destruct,
Up	user_data
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLaddCustomInlineScript(
#ifdef use_prototypes
DtlContextId id,
DtlInlineScriptConstructProc construct,
DtlInlineScriptResizeProc resize,
DtlInlineScriptDestroyProc destruct,
Up	udata
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetScriptFunctions(
#ifdef use_prototypes
DtlContextId	id,
char	*script_name,
DtlScriptConstructProc	*construct,
DtlScriptRefreshProc	*refresh,
DtlScriptDestructProc	*destruct,
Up	*user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetAnnotScriptFunctions(
#ifdef use_prototypes
DtlContextId	id,
char	*script_name,
DtlAnnotScriptConstructProc	*construct,
DtlAnnotScriptRefreshProc	*refresh,
DtlAnnotScriptDestructProc	*destruct,
Up	*user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddApplicationCallback(
#ifdef use_prototypes
DtlContextId	id,
int	which,
DtlApplicationCallbackProc	callback,
Up	user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqApplicationCallback(
#ifdef use_prototypes
DtlContextId			id,
int				which,
DtlApplicationCallbackProc	*callback,
Up				*user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddPropertyValueFunction(
#ifdef use_prototypes
DtlContextId id, 
char *name, 
DtlPropertyValueProc func
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddwPropertyValueFunction(
#ifdef use_prototypes
DtlContextId id, 
char *name, 
DtlwPropertyValueProc func,
Up user_data
#endif
);


extern
DTL_EXPORT
int
OS_PASCAL
DTLgetCurrentValues(
#ifdef use_prototypes
DtlContextId    id,
DtlBookId       *bid,
char    **bookname,
unsigned long *eid
#endif
);


#endif /* DTL__SIT_DEFS */


/*** Help Routines ***/

extern 
DTL_EXPORT
int
OS_PASCAL
DTLshowHelp(
#ifdef use_prototypes
DtlContextId id, 
char *which
#endif 
);


/** Menu prototypes
Here be the prototypes for the DTLmenu package.
**/

extern
DTL_EXPORT
DtlMenuItemId
OS_PASCAL
DTLmenuAddViewItem(
#ifdef use_prototypes
DtlViewId         viewId,
const char       *text, 
DtlMenuItemFlags  item_flags,
DtlMenuItemProc   callback, 
Up                user_data
#endif
);

extern
DTL_EXPORT
DtlMenuItemId
OS_PASCAL
DTLmenuAddGraphicItem(
#ifdef use_prototypes
DtlGraphicId      graphicId,
const char       *name, 
DtlMenuItemFlags  item_flags,
DtlMenuItemProc   callback, 
Up                user_data
#endif
);

extern
DTL_EXPORT
DtlMenuItemId
OS_PASCAL
DTLmenuAddColWinItem(
#ifdef use_prototypes
DtlColWinId       colWinId,
const char       *name, 
DtlMenuItemFlags  item_flags,
DtlMenuItemProc   callback, 
Up                user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuRenameItem(
#ifdef use_prototypes
DtlMenuItemId     menuItemId, 
const char       *text
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuRemoveItem(
#ifdef use_prototypes
DtlMenuItemId     menuItemId
#endif
);

extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLmenuInqView(
#ifdef use_prototypes
DtlMenuItemId     menuItemId
#endif
);

extern
DTL_EXPORT
DtlGraphicId
OS_PASCAL
DTLmenuInqGraphic(
#ifdef use_prototypes
DtlMenuItemId     menuItemId 
#endif
);

extern
DTL_EXPORT
DtlColWinId
OS_PASCAL
DTLmenuInqColWin(
#ifdef use_prototypes
DtlMenuItemId     menuItemId 
#endif
);

extern
DTL_EXPORT
DtlWindowType
OS_PASCAL
DTLmenuInqWindowType(
#ifdef use_prototypes
DtlMenuItemId     menuItemId 
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuEnableItem(
#ifdef use_prototypes
DtlMenuItemId     menuItemId, 
int               enableitem
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuInqItemEnabled(
#ifdef use_prototypes
DtlMenuItemId     menuItemId,  
int              *enabled
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuCheckItem(
#ifdef use_prototypes
DtlMenuItemId     menuItemId, 
int               check
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuInqItemChecked(
#ifdef use_prototypes
DtlMenuItemId     menuItemId, 
int              *checked
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmenuInqItemInternal(
#ifdef use_prototypes
DtlMenuItemId     menuItemId, 
Up               *return_value
#endif 
);



/** Book Prototypes
We specify the routines associated with a DTL book.
**/

/*** Main Routines ***/
extern
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLnewBook(
#ifdef use_prototypes
DtlContextId	id,
char	*book_dbase,
char	*book_name,
DtlBookCallbackProc	close_callback,
Up	user_data,
long	flags
#endif
);

extern
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLopenCachedBook(
#ifdef use_prototypes
DtlContextId	id,
char	*book_dbase,
char	*book_name
#endif
);

extern
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLADIopenCachedBook(
#ifdef use_prototypes
DtlContextId contextId,
char *bookPath,
char *adiImpl,
char *bookAlias
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLcloseCachedBook(
#ifdef use_prototypes
DtlBookId	bid
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLloadToc(
#ifdef use_prototypes
DtlBookId	bid,
char	*name
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyBook(
#ifdef use_prototypes
DtlBookId	bid
#endif
);


/*** Interface Routines ***/
/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateTocWindow(
#ifdef use_prototypes
DtlBookId	bid,
char	*name,
char	*title
#endif
);


#ifdef DTL__SIT_DEFS


#ifdef DTL__X_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateTocWindowFromX(
#ifdef use_prototypes
DtlBookId	bid,
Widget	parent
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
Widget
OS_PASCAL
DTLinqTocWidget(
#ifdef use_prototypes
DtlBookId	bid
#endif
);


#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateTocWindowFromWindows(
#ifdef use_prototypes
DtlBookId	bid,
HWND	parent
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
HWND
OS_PASCAL
DTLinqTocHWND(
#ifdef use_prototypes
DtlBookId	bid
#endif
);


#endif /* DTL__WINDOWS_DEFS */

#endif /* DTL__SIT_DEFS */

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLmapTocWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapTocWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateLookupWindow(
#ifdef use_prototypes
DtlBookId	bid,
char	*name,
char	*title
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLmapLookupWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapLookupWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLcreateAnnotationWindow(
#ifdef use_prototypes
DtlBookId	bid,
char	*name,
char	*title
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLmapAnnotationWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapAnnotationWindow(
#ifdef use_prototypes
DtlBookId	bid
#endif
);




#ifdef DTL__SIT_DEFS

/** Callback Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddBookCallback(
#ifdef use_prototypes
DtlBookId bid, 
int which,
DtlBookCallbackProc callback, 
Up data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqBookCallback(
#ifdef use_prototypes
DtlBookId 		bid, 
int 			which,
DtlBookCallbackProc 	*callback, 
Up 			*data
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLsetTocCallback(
#ifdef use_prototypes
DtlBookId bid, 
DtlBookCallbackProc callback, 
Up data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqTocCallback(
#ifdef use_prototypes
DtlBookId 		bid, 
DtlBookCallbackProc 	*callback, 
Up 			*data
#endif
);

#endif /* DTL__SIT_DEFS */


/*** Misc Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLredrawAllViews(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetActiveView(
#ifdef use_prototypes
DtlBookId	bid,
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLinqActiveView(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
DtlContextId
OS_PASCAL
DTLinqContext(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqBookName(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwInqBookName(
#ifdef use_prototypes
   DtlBookId	bookId
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqBookDbase(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqBookAlias(
#ifdef use_prototypes
DtlBookId	bid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetBookAlias(
#ifdef use_prototypes
DtlBookId	bid,
char*       alias					 
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLscriptEvaluate(
#ifdef use_prototypes
DtlBookId	bid,
unsigned long	eid,
char *		expression,
char		buffer[],
int		length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwScriptEvaluate(
#ifdef use_prototypes
DtlBookId		bid,
unsigned long	eid,
UCSchar16 *		expression,
UCSchar16		buffer[],
size_t			length
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLmultiBookScriptEvaluate(
#ifdef use_prototypes
DtlBookId       bid,
DtlBookId       dbid,
unsigned long   eid,
char *          expression,
char            buffer[],
int             length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwMultiBookScriptEvaluate(
#ifdef use_prototypes
DtlBookId       bid,
DtlBookId       dbid,
unsigned long   eid,
UCSchar16 *     expression,
UCSchar16       buffer[],
size_t          length
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetElementScript(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long eid, 
char scr[], 
char parms[], 
int maxbuf
#endif
);

extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLgetActiveMDIView(
#ifdef use_prototypes
DtlContextId	id
#endif
);

extern
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLnewAssociatedTocView(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
DtlGuiId
OS_PASCAL
DTLinqViewComponent(
#ifdef use_prototypes
DtlViewId         vid,
DtlViewComponent  cmp
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetViewLayout(
#ifdef use_prototypes
DtlViewId       vid,
DtlViewLayout  *viewLayout
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetViewLayout(
#ifdef use_prototypes
DtlViewId       vid,
DtlViewLayout   viewLayout
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLperformViewMenuAction(
#ifdef use_prototypes							
DtlViewId   vid,
Up          menuItem
#endif
);



#ifdef DTL__SIT_DEFS



/** Database Prototypes
We specify the routines associated with database queries.
**/

extern 
DTL_EXPORT
int
OS_PASCAL
DTLgetNodeInfo(
#ifdef use_prototypes
	DtlBookId bookId,
	unsigned long root
#endif
);

/*** Query Routines ***/
extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetTag(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	buf[],
int	buf_length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetTag(
#ifdef use_prototypes
   DtlBookId		bookId, 
   unsigned long	elementId,
   UCSchar16		buf[],
   size_t			buf_length
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetFullTag(
#ifdef use_prototypes
DtlBookId     bid, 
unsigned long eid,
char  buf[],
int   buf_length
#endif
);
  
extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetFullTag(
#ifdef use_prototypes
   DtlBookId          bookId, 
   unsigned long      elementId,
   UCSchar16          buf[],
   size_t                     buf_length
#endif
);


extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetAttributes(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	buf[],
int	buf_length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetAttributes(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
UCSchar16	buf[],
size_t	buf_length
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetAttr(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	*attrname,
char	attrval[],
int	buf_length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetAttr(
#ifdef use_prototypes
   DtlBookId		bookId, 
   unsigned long	elementId,
   UCSchar16	*	attrname,
   UCSchar16		attrval[],
   size_t			buf_len
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetText(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	buf[],
int	buf_length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetText(
#ifdef use_prototypes
   DtlBookId		bookId, 
   unsigned long	elementId,
   UCSchar16		buf[],
   size_t			buf_length
#endif
);


extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetAllText(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	buf[],
int	buf_length
#endif
);

extern
DTL_EXPORT
UCSchar16 *
OS_PASCAL
DTLwGetAllText(
#ifdef use_prototypes
   DtlBookId		bookId, 
   unsigned long	elementId,
   UCSchar16		buf[],
   size_t			buf_length
#endif
);


/*** Tree Routines ***/

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetParent(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetFirstChild(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetRightSister(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetLeftSister(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetPrev(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetNext(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetNamedChild(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	*childtag
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetNamedAncestor(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	eid,
char	*tag
#endif
);

extern
DTL_EXPORT
double
OS_PASCAL
DTLgetPosition(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	root,
unsigned long	eid
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetNumElements(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	root
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetLastElement(
#ifdef use_prototypes
DtlBookId	bid, 
unsigned long	root
#endif
);

#endif /* DTL__SIT_DEFS */



#ifdef DTL__SIT_DEFS

/** Query Prototypes
**/


/*** Query Routines ***/
extern
DTL_EXPORT
DtlQueryId
OS_PASCAL
DTLnewQuery(
#ifdef use_prototypes
DtlBookId	bid, 
char	*query,
int	options
#endif
);

extern 
DTL_EXPORT
DtlQueryId
OS_PASCAL
DTLmergeQueries(
#ifdef use_prototypes
DtlQueryId qid1, 
DtlQueryId qid2, 
int op
#endif
);

extern
DTL_EXPORT
DtlQueryId
OS_PASCAL
DTLnewFakeQuery(
#ifdef use_prototypes
DtlBookId bid, 
long num_hits, 
unsigned long eids[]
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLcancelQuery(
#ifdef use_prototypes
DtlBookId bid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLqueryCancel(
#ifdef use_prototypes
DtlBookId bid
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyQuery(
#ifdef use_prototypes
DtlQueryId	qid
#endif
);


/*** Update Routines ***/
/* PHASING OUT AFTER 2.0 */
int
OS_PASCAL
DTLqueryUpdateToc(
#ifdef use_prototypes
DtlQueryId	qid,
DtlBookId	bid,
int	feedback
#endif
);         

int
OS_PASCAL
DTLqueryUpdateTocView(
#ifdef use_prototypes
DtlQueryId	qid,
DtlTocViewId	tid,
int	feedback
#endif
);         

int
OS_PASCAL
DTLqueryUpdateFulltext(
#ifdef use_prototypes
DtlQueryId	qid,
DtlViewId	vid,
int	redraw
#endif
);         

int
OS_PASCAL
DTLqueryUpdateFulltextNext(
#ifdef use_prototypes
DtlQueryId	qid,
DtlViewId	vid,
int	redraw
#endif
);         

int
OS_PASCAL
DTLqueryNextFulltext(
#ifdef use_prototypes
DtlQueryId	qid,
DtlViewId	vid
#endif
);         

int
OS_PASCAL
DTLqueryPreviousFulltext(
#ifdef use_prototypes
DtlQueryId	qid,
DtlViewId	vid
#endif
);         

int
OS_PASCAL
DTLqueryFirstFulltext(
#ifdef use_prototypes
DtlQueryId	qid,
DtlViewId	vid
#endif
);         

/*** Modify display ***/
void
OS_PASCAL
DTLsetQueryFeedbackMode(
#ifdef use_prototypes
DtlContextId id,
int mode
#endif
);


/*** Generator Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLqueryStartSequence(
#ifdef use_prototypes
DtlQueryId	qid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLqueryNextSequence(
#ifdef use_prototypes
DtlQueryId	qid,
unsigned long	*eid1,
unsigned long	*eid2,
int	*off1,
int	*off2
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLqueryGetFreq(
#ifdef use_prototypes
DtlQueryId	qid,
unsigned long	eid
#endif
);

#endif /* DTL__SIT_DEFS */



#ifdef DTL__SIT_DEFS 

/** DTL Library Level Querying
Library Level Querying:
**/

extern
DTL_EXPORT
DtlLibQueryId
OS_PASCAL
DTLnewLibQuery(
#ifdef use_prototypes
DtlContextId	id,
char	*dbase,
char	*query,
long	options
#endif
);

extern 
DTL_EXPORT
long
OS_PASCAL
DTLlibQuery(
#ifdef use_prototypes
DtlLibQueryId qid,
char *dbase,
char *book,
long flags	    
#endif
);

extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyLibQuery(
#ifdef use_prototypes
DtlLibQueryId	qid
#endif
);

#endif /* DTL__SIT_DEFS */



#ifdef DTL__SIT_DEFS 

/** Annotation Prototypes
**/

extern 
DTL_EXPORT
int
OS_PASCAL
DTLclearAnnotations(
#ifdef use_prototypes
DtlBookId bid
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLaddAnnotation(
#ifdef use_prototypes
DtlBookId bid, unsigned long element, char *title,
int genre, char *ascript, char *script, char *parms
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLdeleteAnnotation(
#ifdef use_prototypes
DtlBookId bid, unsigned long element, char *title
#endif
);


extern 
DTL_EXPORT
int
OS_PASCAL
DTLsaveAnnotations(
#ifdef use_prototypes
DtlBookId bid, int genre, char *path
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLloadAnnotations(
#ifdef use_prototypes
DtlBookId bid, char *path
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLstartAnnotationSequence(
#ifdef use_prototypes
DtlBookId bid, unsigned long element
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLnextAnnotationSequence(
#ifdef use_prototypes
DtlBookId bid, 
DtlAnnotStruct *rec
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLgetAnnotationInfo(
#ifdef use_prototypes
DtlBookId bid, DtlAnnotStruct *rec, 
unsigned long eid, int num
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLstartFullAnnotationSequence(
#ifdef use_prototypes
DtlBookId bookId
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLnextFullAnnotationSequence(
#ifdef use_prototypes
DtlBookId bookId,
unsigned long *eid,
DtlAnnotStruct *annotationStruct
#endif
);

#endif /* DTL__SIT_DEFS */

extern 
DTL_EXPORT
int
OS_PASCAL
DTLaddAnnotationAsUser(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long eid, 
char *title, 
int genre, 
char *ascript
#endif
);


/** DtlTocView Routines
**/

#ifdef DTL__SIT_DEFS


extern
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLnewTocViewFromGUI(
#ifdef use_prototypes
DtlBookId	bid,
DtlGuiId	parent,
char	*viewname,
unsigned long root,
DtlTocViewCallbackProc	close_cb,
Up	data,
long	flags
#endif
);

extern
DTL_EXPORT
DtlGuiId
OS_PASCAL
DTLinqTocViewGUI(
#ifdef use_prototypes
DtlTocViewId	tid
#endif
);

#ifdef DTL__X_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLnewTocViewFromX(
#ifdef use_prototypes
DtlBookId	bid,
Widget	parent,
char	*viewname,
unsigned long root,
DtlTocViewCallbackProc	close_cb,
Up	data,
long	flags
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
Widget
OS_PASCAL
DTLinqTocViewWidget(
#ifdef use_prototypes
DtlTocViewId	tid
#endif
);

#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLnewTocViewFromWindows(
#ifdef use_prototypes
DtlBookId	bid,
HWND	parent,
char	*viewname,
unsigned long root,
DtlTocViewCallbackProc	close_cb,
Up	data,
long	flags
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
HWND
OS_PASCAL
DTLinqTocViewHWND(
#ifdef use_prototypes
DtlTocViewId	tid
#endif
);

#endif /* DTL__WINDOWS_DEFS */

#endif /* DTL__SIT_DEFS */

extern 
DTL_EXPORT
void
OS_PASCAL
DTLdestroyTocView(
#ifdef use_prototypes
DtlTocViewId	tid
#endif
);

extern
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLinqTocViewBook(
#ifdef use_prototypes
DtlTocViewId	tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLtocViewReloadStyleSheet(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLflushStyleSheetCache(
#ifdef use_prototypes
DtlContextId id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLresetTocView(
#ifdef use_prototypes
DtlTocViewId	tid,
unsigned long root_element,
char	*viewname
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddTocViewCallback(
#ifdef use_prototypes
DtlTocViewId	tid,
int	which,
DtlTocViewCallbackProc	close_cb,
Up	user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqTocViewCallback(
#ifdef use_prototypes
DtlTocViewId		tid,
int			which,
DtlTocViewCallbackProc	*close_cb,
Up			*user_data
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetTocSize(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetTocLevel(
#ifdef use_prototypes
DtlTocViewId tid,
long	idx
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetTocElement(
#ifdef use_prototypes
DtlTocViewId tid,
long	idx
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetTocRecord(
#ifdef use_prototypes
DtlTocViewId tid,
unsigned long	eid
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetTocRecordText(
#ifdef use_prototypes
DtlTocViewId tid,
long	entry,
char  buf[],
int   buf_size
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetTocActiveRecord(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLsetTocActiveSection(
#ifdef use_prototypes
DtlTocViewId tid,
unsigned long	eid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLexpandToc(
#ifdef use_prototypes
DtlTocViewId tid,
long	idx
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLcollapseToc(
#ifdef use_prototypes
DtlTocViewId tid,
long	idx
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetTocTop(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetTocBottom(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollToc(	
#ifdef use_prototypes
DtlTocViewId tid,
long	idx
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLscrollTocToElement(
#ifdef use_prototypes
DtlTocViewId tid, 
unsigned long eid
#endif
);


#ifdef DTL__SIT_DEFS

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetTocSelectionStatus(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetTocViewMode(
#ifdef use_prototypes
DtlTocViewId tvid,
int mode,
int method
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqTocViewMode(
#ifdef use_prototypes
DtlTocViewId tvid,
int mode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLremoveTocViewScrollbars(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollTocViewUp(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollTocViewDown(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlineScrollTocViewUp(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlineScrollTocViewDown(
#ifdef use_prototypes
DtlTocViewId tvid
#endif
);

#endif /* DTL__SIT_DEFS */


extern
DTL_EXPORT
int
OS_PASCAL
DTLmapTocView(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapTocView(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLenableTocView(
#ifdef use_prototypes
DtlTocViewId tid,
int          on_or_off
#endif           
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLraiseTocView(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLstartTocViewWait(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLendTocViewWait(
#ifdef use_prototypes
DtlTocViewId tid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLcopyToc(
#ifdef use_prototypes
DtlTocViewId tid,
int	mode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetTocMode(
#ifdef use_prototypes
DtlTocViewId tid,
int	mode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetTocViewZoomFactor(
#ifdef use_prototypes
DtlTocViewId vid,
double	zoom_factor
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLzoomTocView(
#ifdef use_prototypes
DtlTocViewId tvid,
double zoom_factor
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgenerateTocSelections(
#ifdef use_prototypes
DtlTocViewId tvid, 
DtlTocViewGeneratorProc cb, 
Up data
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLselectTocRecord(
#ifdef use_prototypes
DtlTocViewId tvid, long idx, int on_or_off
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLselectTocElement(
#ifdef use_prototypes
DtlTocViewId tvid, unsigned long eid, int on_or_off
#endif
);

#ifdef DTL__SIT_DEFS


/** Print System Prototypes
**/

extern
DTL_EXPORT
DtlPrintId
OS_PASCAL
DTLnewPrintContext(
#ifdef use_prototypes
DtlBookId	bid,
char	*stylesheet,
FILE	*fp
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLprintCancel(
#ifdef use_prototypes
DtlPrintId printContextId
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintElement(
#ifdef use_prototypes
DtlPrintId	pid,
unsigned long	eid,
int	flags
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintGraphic(
#ifdef use_prototypes
DtlPrintId	pid,
char	*parameters
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintGraphicImage(
#ifdef use_prototypes
DtlPrintId	pid,
char	*parameters,
int	gtype
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyPrintContext(
#ifdef use_prototypes
DtlPrintId	pid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintControl(
#ifdef use_prototypes
DtlPrintId	pid,
long		flags
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLprintSections(
#ifdef use_prototypes
DtlBookId	bid,
char	*stylesheet,
FILE	*fp
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintTocViewSections(
#ifdef use_prototypes
DtlTocViewId	tid,
char	*stylesheet,
FILE	*fp
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLprintViewSections(
#ifdef use_prototypes
DtlViewId vid
#endif
);


#endif /* DTL__SIT_DEFS */





#ifdef DTL__SIT_DEFS


/** History Prototypes
**/


/*** Main Routines ***/

extern
DTL_EXPORT
DtlHistoryId
OS_PASCAL
DTLnewHistory(
#ifdef use_prototypes
DtlContextId	id,
int	max_size
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmapHistory(
#ifdef use_prototypes
DtlHistoryId	id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapHistory(
#ifdef use_prototypes
DtlHistoryId	id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLraiseHistory(
#ifdef use_prototypes
DtlHistoryId	id
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyHistory(
#ifdef use_prototypes
DtlHistoryId	hid
#endif
);


/*** Edit Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddHistoryItem(
#ifdef use_prototypes
DtlHistoryId hid,
int	pos,
DtlViewId	vid,
unsigned long eid,
char	*title
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLdeleteHistoryItem(
#ifdef use_prototypes
DtlHistoryId hid,
int	pos
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLloadHistory(
#ifdef use_prototypes
DtlHistoryId hid,
char *path
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsaveHistory(
#ifdef use_prototypes
DtlHistoryId hid,
char *path
#endif
);

/*** Action Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLtoggleHistory(
#ifdef use_prototypes
DtlHistoryId	hid,
int	on_or_off
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLinqHistorySerialNumber(
#ifdef use_prototypes
DtlHistoryId	hid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqHistorySize(
#ifdef use_prototypes
DtlHistoryId	hid
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqHistoryBook(
#ifdef use_prototypes
DtlHistoryId	hid,
int	which
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqHistoryView(
#ifdef use_prototypes
DtlHistoryId	hid,
int	which
#endif
);

extern
DTL_EXPORT
unsigned long 
OS_PASCAL
DTLinqHistoryRoot(
#ifdef use_prototypes
DtlHistoryId	hid,
int	which
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLinqHistoryElement(
#ifdef use_prototypes
DtlHistoryId	hid,
int	which
#endif
);


extern
OS_CONST
DTL_EXPORT
char *
OS_PASCAL
DTLinqHistoryTitle(
#ifdef use_prototypes
DtlHistoryId      hid,
int     	  index
#endif
);


#endif /* DTL__SIT_DEFS */



/** View Prototypes
We specify the routines with a DTL view.
**/

/*** Main Routines ***/
extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnewView(
#ifdef use_prototypes
DtlBookId	bid,
char	*name,
char	*title,
char	*viewname,
unsigned long root_element,
DtlViewCallbackProc	close_callback,
Up	user_data,
long	flags
#endif
);

#ifdef DTL__SIT_DEFS

extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnewViewFromGUI(
#ifdef use_prototypes
DtlBookId	bid,
DtlGuiId	gui,
char	*viewname,
unsigned long root_element,
DtlViewCallbackProc	close_callback,
Up	user_data,
long	flags
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLisViewFromGUI(
#ifdef use_prototypes
DtlViewId	viewId
#endif
);


#ifdef DTL__X_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnewViewFromX(
#ifdef use_prototypes
DtlBookId	bid,
Widget	parent,
char	*viewname,
unsigned long root_element,
DtlViewCallbackProc	close_callback,
Up	user_data,
long	flags
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
Widget
OS_PASCAL
DTLinqViewWidget(
#ifdef use_prototypes
DtlViewId	vid
#endif
);


extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnewCustomViewFromX(
#ifdef use_prototypes
		     Widget parent,
		     DtlBookId bid,
		     char *name,
		     char *title,
		     char *viewname,
		     char *tocViewName,
		     unsigned long root_element, 
		     DtlViewLayout viewLayout,
		     long flags
#endif
);


#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLnewViewFromWindows(
#ifdef use_prototypes
DtlBookId	bid,
HWND	parent,
char	*viewname,
unsigned long root_element,
DtlViewCallbackProc	close_callback,
Up	user_data,
long	flags
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
HWND
OS_PASCAL
DTLinqViewHWND(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

#endif /* DTL__WINDOWS_DEFS */

#endif /* DTL__SIT_DEFS */


extern
DTL_EXPORT
int
OS_PASCAL
DTLviewSetBook(
#ifdef use_prototypes
DtlViewId vid,
DtlBookId bid,
unsigned long root,
char *stylesheet,
char *toc_stylesheet
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLviewSetTitle(
#ifdef use_prototypes
DtlViewId vid,
char *title
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLviewReloadStyleSheet(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLresetView(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long root, 
char *stylesheet
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLresetRevelatoryView(
#ifdef use_prototypes
DtlViewId vid, 
int	revelatory
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLresetViewToc(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long root, 
char *viewname
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);


/*** Edit Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLsetViewMode(
#ifdef use_prototypes
DtlViewId vid,
int	mode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLcopyView(
#ifdef use_prototypes
DtlViewId vid,
int	mode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetViewSelection(
#ifdef use_prototypes
DtlViewId vid,
unsigned long *eid1,
long	*offset1,
unsigned long *eid2,
long *offset2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetViewSelection(
#ifdef use_prototypes
DtlViewId vid,
unsigned long eid1,
long	offset1,
unsigned long eid2,
long offset2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetViewZoomFactor(
#ifdef use_prototypes
DtlViewId vid,
double	zoom_factor
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLzoomView(
#ifdef use_prototypes
DtlViewId vid,
double	zoom_factor
#endif
);

/*** Interface Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLmapView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLmapViewWithToc(
#ifdef use_prototypes
   DtlViewId viewId,
   int       showtoc
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLenableView(
#ifdef use_prototypes
DtlViewId   vid,
int         on_or_off
#endif           
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmapViewToc(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapViewToc(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLraiseView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
DtlGuiId
OS_PASCAL
DTLinqViewGUI(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern 
DTL_EXPORT
int
OS_PASCAL
DTLsuggestViewGeometry(
#ifdef use_prototypes
DtlViewId	vid,
int	width,
int	height
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLredrawView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLrebuildView(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmapAnnotWindow(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapAnnotWindow(
#ifdef use_prototypes
DtlViewId	vid
#endif
);


/*** Action Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollView(
#ifdef use_prototypes
DtlViewId	vid,
unsigned long	element_id,
int		forward
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLhscrollView(
#ifdef use_prototypes
DtlViewId       vid,
long            pos
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlaunchScript(
#ifdef use_prototypes
DtlViewId	vid,
unsigned long	element_id
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlaunchAnnot(
#ifdef use_prototypes
DtlViewId	vid,
unsigned long	element_id,
char	*title
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLviewGoBack(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLstartViewWait(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLendViewWait(
#ifdef use_prototypes
DtlViewId vid
#endif
);


#ifdef DTL__SIT_DEFS

/*** Graphics Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLperformViewQuery(
#ifdef use_prototypes
DtlViewId vid, 
char * query
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLremoveViewScrollbars(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLgetViewHorizPos(
#ifdef use_prototypes
DtlViewId vid
#endif
);


extern
DTL_EXPORT
long
OS_PASCAL
DTLgetViewHorizMax(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollViewUp(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLscrollViewDown(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlineScrollViewUp(
#ifdef use_prototypes
DtlViewId vid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlineScrollViewDown(
#ifdef use_prototypes
DtlViewId vid
#endif
);

#endif /* DTL__SIT_DEFS */


/*** Position Routines ***/
extern
DTL_EXPORT
int
OS_PASCAL
DTLreportTopPosition(
#ifdef use_prototypes
DtlViewId	vid,
unsigned long	*element_id,
char	attributes[],
int	attribute_max_length
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLreportBottomPosition(
#ifdef use_prototypes
DtlViewId	vid,
unsigned long	*element_id,
char	attributes[],
int	attribute_max_length
#endif
);

extern
DTL_EXPORT
long
OS_PASCAL
DTLreportElementHeight(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long eid, 
int w
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLisElementVisible(
#ifdef use_prototypes
DtlViewId vid, 
unsigned long eid 
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLreportViewElements(
#ifdef use_prototypes
DtlViewId vid, 
DtlElemGeom **geoms, 
long *num
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLfreeElemGeoms(
#ifdef use_prototypes
DtlViewId vid, 
DtlElemGeom *geoms 
#endif
);

/*** Inquire Routines ***/
extern
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLinqBook(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLinqRootElement(
#ifdef use_prototypes
DtlViewId	vid
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLinqViewName(
#ifdef use_prototypes
DtlViewId	vid
#endif
);


#ifdef DTL__SIT_DEFS


/*** View Inquiry Routines ***/
extern
DTL_EXPORT
DtlQueryId
OS_PASCAL
DTLinqViewQuery(
#ifdef use_prototypes
DtlViewId       vid
#endif
);


/*** Script Support Routines ***/

extern
DTL_EXPORT
void
OS_PASCAL
DTLremoveExref(
#ifdef use_prototypes
DtlViewId	vid,
DtlExrefId	exid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddViewCallback(
#ifdef use_prototypes
DtlViewId	vid,
int	which,
DtlViewCallbackProc	callback,
Up	user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqViewCallback(
#ifdef use_prototypes
DtlViewId		vid,
int			which,
DtlViewCallbackProc	*callback,
Up			*user_data
#endif
);

#endif /* DTL__SIT_DEFS */

extern
DTL_EXPORT
void
OS_PASCAL
DTLcloseAllExrefs(
#ifdef use_prototypes
DtlViewId	vid
#endif
);



/** Raster Prototypes
We specify the routines with a DTL raster object.
**/

#ifdef DTL__SIT_DEFS

/*** Main Routines ***/

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlRasterId
OS_PASCAL
DTLnewRaster(
#ifdef use_prototypes
DtlContextId	id,
char	*title
#endif
);


#ifdef DTL__X_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlRasterId
OS_PASCAL
DTLnewRasterFromX(
#ifdef use_prototypes
DtlContextId	id,
Widget	parent
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
Widget
OS_PASCAL
DTLinqRasterWidget(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlRasterId
OS_PASCAL
DTLnewRasterFromWindows(
#ifdef use_prototypes
DtlContextId	id,
HWND	parent
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
HWND
OS_PASCAL
DTLinqRasterHWND(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

#endif /* DTL__WINDOWS_DEFS */


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLloadRasterFile(
#ifdef use_prototypes
DtlRasterId	rid,
char	*path
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyRaster(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);


/*** Graphics Routines ***/

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLmapRaster(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapRaster(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLraiseRaster(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLlowerRaster(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);



/*** Pick Routines ***/
/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLaddRasterCallback(
#ifdef use_prototypes
DtlRasterId	rid,
int	which,
DtlRasterCallbackProc	callback,
Up	user_data
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLhighlightRasterRegion(
#ifdef use_prototypes
DtlRasterId	rid,
int	x, 
int	y,
int	width, 
int	height
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
int
OS_PASCAL
DTLunhighlightRasterRegion(
#ifdef use_prototypes
DtlRasterId	rid
#endif
);

#endif /* DTL__SIT_DEFS */


/** Graphics Prototypes
We specify the routines with a DTL graphics object.
**/


/*** Main Routines ***/

#ifdef DTL__SIT_DEFS

extern
DTL_EXPORT
DtlGraphicId
OS_PASCAL
DTLnewGraphicFromGUI(
#ifdef use_prototypes
DtlContextId	id,
DtlGuiId	parent,
int	gtype
#endif
);

extern
DTL_EXPORT
DtlGuiId
OS_PASCAL
DTLinqGraphicGUI(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);


#ifdef DTL__X_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlGraphicId
OS_PASCAL
DTLnewGraphicFromX(
#ifdef use_prototypes
DtlContextId	id,
Widget	parent,
int	gtype
#endif
);


/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
Widget
OS_PASCAL
DTLinqGraphicWidget(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

#endif /* DTL__X_DEFS */

#ifdef DTL__WINDOWS_DEFS

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
DtlGraphicId
OS_PASCAL
DTLnewGraphicFromWindows(
#ifdef use_prototypes
DtlContextId	id,
HWND	parent,
int	gtype
#endif
);

/* PHASING OUT AFTER 2.0 */
extern
DTL_EXPORT
HWND
OS_PASCAL
DTLinqGraphicHWND(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

#endif /* DTL__WINDOWS_DEFS */

#endif /* DTL__SIT_DEFS */

/*** Main Routines ***/

extern
DTL_EXPORT
DtlGraphicId
OS_PASCAL
DTLnewGraphic(
#ifdef use_prototypes
DtlContextId	id,
char	*title,
int	gtype
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLloadGraphicFile(
#ifdef use_prototypes
DtlGraphicId	rid,
char	*path
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgraphicZoomToRegion(
#ifdef use_prototypes
DtlGraphicId	gid,
int	x,
int	y,
int	w,
int	h
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgraphicZoomToGraphicRegion(
#ifdef use_prototypes
DtlGraphicId	gid,
double x1,
double y1,
double x2,
double y2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgraphicZoom(
#ifdef use_prototypes
DtlGraphicId	gid,
double	zf
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgraphicZoomReset(
#ifdef use_prototypes
DtlGraphicId	gid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLgetGraphicDimensions(
#ifdef use_prototypes
DtlGraphicId	rid,
int	*ww,
int	*hh		       
#endif
);


extern
DTL_EXPORT
void
OS_PASCAL
DTLdestroyGraphic(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLnormalizeGraphicCoords(
#ifdef use_prototypes
DtlGraphicId	rid,
int x,
int y,
double *normX,
double *normY
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLsetDefaultGraphicGeometry(
#ifdef use_prototypes
DtlGraphicId    rid, 
int             default_width, 
int             default_hgt
#endif
);

/*** Graphics coordinate transformations. ***/

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicCoordTransformGtoW(
#ifdef use_prototypes
DtlGraphicId	rid,
double xG,
double yG,
int *xW,
int *yW
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicCoordTransformWtoG(
#ifdef use_prototypes
DtlGraphicId	rid,
int xW,
int yW,
double *xG,
double *yG
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicCoordTransformGtoH(
#ifdef use_prototypes
DtlGraphicId	rid,
double xG,
double yG,
double *xH,
double *yH
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicCoordTransformHtoG(
#ifdef use_prototypes
DtlGraphicId	rid,
double xH,
double yH,
double *xG,
double *yG
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicWindowExtents(
#ifdef use_prototypes
DtlGraphicId	rid,
int *ulX,
int *ulY,
int *lrX,
int *lrY
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicVisibleGraphicExtents(
#ifdef use_prototypes
DtlGraphicId	rid,
double *ulX,
double *ulY,
double *lrX,
double *lrY
#endif
);

extern
DTL_EXPORT
int 
OS_PASCAL
DTLgraphicOverallGraphicExtents(
#ifdef use_prototypes
DtlGraphicId	rid,
double *ulX,
double *ulY,
double *lrX,
double *lrY
#endif
);


/*** Graphics Routines ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLmapGraphic(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunmapGraphic(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLraiseGraphic(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLlowerGraphic(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);


extern
DTL_EXPORT
int
OS_PASCAL
DTLenableGraphic(
#ifdef use_prototypes
DtlGraphicId   rid,
int            on_or_off
#endif           
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLremoveGraphicScrollbars(
#ifdef use_prototypes
DtlGraphicId gid
#endif
);


/*** Pick Routines ***/

#ifdef DTL__SIT_DEFS

extern
DTL_EXPORT
int
OS_PASCAL
DTLaddGraphicCallback(
#ifdef use_prototypes
DtlGraphicId	rid,
int	which,
DtlGraphicCallbackProc	callback,
Up	user_data
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLinqGraphicCallback(
#ifdef use_prototypes
DtlGraphicId		rid,
int			which,
DtlGraphicCallbackProc	*callback,
Up			*user_data
#endif
);

#endif /* DTL__SIT_DEFS */

extern
DTL_EXPORT
int
OS_PASCAL
DTLhighlightGraphicRegion(
#ifdef use_prototypes
DtlGraphicId	rid,
int	x, 
int	y,
int	width, 
int	height
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunhighlightGraphicRegion(
#ifdef use_prototypes
DtlGraphicId	rid
#endif
);



/** Utility System Prototypes
We specify the DTL utility routines.
**/

extern
DTL_EXPORT
char *
OS_PASCAL
DTLparseAttribute(
#ifdef use_prototypes
DtlContextId	id,
char	*string,
char	*aname,
char 	vbuf[],
int	buf_size
#endif
);


/* PHASING OUT AFTER 2.0 */
#define DTLgetAttribute(a,b,c,d,e) DTLparseAttribute(a,b,c,d,e)


extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLgetElement(
#ifdef use_prototypes
DtlBookId	bid,
char	*aname,
char	*aval
#endif
);

extern 
DTL_EXPORT
DtlBookId
OS_PASCAL
DTLgetBook(
#ifdef use_prototypes
DtlContextId id, 
char *dbase, 
char *book_name
#endif
);

extern 
DTL_EXPORT
DtlViewId
OS_PASCAL
DTLgetView(
#ifdef use_prototypes
DtlContextId id, 
char *dbase, 
char *book_name, 
char *view_name, 
unsigned long root
#endif
);


extern 
DTL_EXPORT
DtlTocViewId
OS_PASCAL
DTLgetTocView(
#ifdef use_prototypes
DtlContextId id, 
char *dbase, 
char *book_name, 
char *view_name, 
unsigned long root
#endif
);

/** Plugin Support Routines 
**/

extern
DTL_EXPORT
int
OS_PASCAL
DTLpluginInit(
#ifdef use_prototypes
        DtlPluginInfoId pluginInfoId,
        char *pluginList,
        char *pluginDirs	      
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLpluginAdd(
#ifdef use_prototypes
        DtlPluginInfoId pluginInfoId,
        char *path,
        char *init,
	char *destroy
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLpluginSetDestroyCallback(
#ifdef use_prototypes
        DtlPluginId plugin,
	Up destroy
#endif
);

extern
DTL_EXPORT
Up
OS_PASCAL
DTLpluginInqDestroyCallback(
#ifdef use_prototypes
        DtlPluginId plugin
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLsetMaxFds(
#ifdef use_prototypes
   	DtlContextId contextId, 
	int maxFds
#endif
);

/** Locale and Conversion routines
**/

extern
DTL_EXPORT
void
OS_PASCAL
DTLunicode2native(
#ifdef use_prototypes
UCSchar16 *unicode,
char *native,
size_t numChars
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLunicode2multibyte(
#ifdef use_prototypes
UCSchar16 *unicode, 
char *multibyte,	
char *encodingName,
size_t numChars
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLnative2unicode(
#ifdef use_prototypes
char *native,
UCSchar16 *unicode,
size_t numUCSchar16s
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLmultibyte2unicode(
#ifdef use_prototypes
char *multibyte, 
UCSchar16 *unicode, 
char *encodingName,
size_t numUCSchar16s
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLunicodeLength(
#ifdef use_prototypes
UCSchar16 * unicode
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLnativeMaxPerChar(
#ifdef use_prototypes
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLmultibyteMaxPerChar(
#ifdef use_prototypes
char *encodingName
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetLocale(
#ifdef use_prototypes
#endif
);

extern
DTL_EXPORT
void *
OS_PASCAL
DTLinqBookInternal(
#ifdef use_prototypes
DtlBookId dtlBookId,
char *internalDataMember
#endif
);

extern
DTL_EXPORT
void *
OS_PASCAL
DTLinqContextInternal(
#ifdef use_prototypes
DtlContextId contextId,
char *internalDataMember
#endif
);

#ifdef DTL__WINDOWS_DEFS

extern
DTL_EXPORT
HANDLE
OS_PASCAL
DTLdllInqHINSTANCE(
#ifdef use_prototypes
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLdllInqRefcount(
#ifdef use_prototypes
#endif
);

#endif /* DTL__WINDOWS_DEFS */

/*** DTLNODE functions ***/

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisBefore(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisAfter(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisEqual(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisParent(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisChild(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisAncestor(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisDescendant(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEisSibling(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid1,
unsigned long eid2
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEwEid2name(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid,
int persistence_level,
UCSchar16* name,
int maxbuf
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEeid2name(
#ifdef use_prototypes
DtlBookId bid,
unsigned long eid,
int persistence_level,
char* name,
int maxbuf
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLNODEname2eid(
#ifdef use_prototypes
DtlBookId bid,
char* name
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLNODEwName2eid(
#ifdef use_prototypes
DtlBookId bid,
UCSchar16 *name
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLNODEeid2globalNumber(
#ifdef use_prototypes
DtlBookId bid,unsigned long eid
#endif
);

extern
DTL_EXPORT
unsigned long
OS_PASCAL
DTLNODEglobalNumber2eid(
#ifdef use_prototypes
DtlBookId bid,
unsigned long global
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEnameLength(
#ifdef use_prototypes
char* name
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLNODEwNameLength(
#ifdef use_prototypes
UCSchar16* name
#endif
);

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetExePath();

extern
DTL_EXPORT
char *
OS_PASCAL
DTLgetIniFilePath(
#ifdef use_prototypes
const char *szIniFilename
#endif
);

extern
DTL_EXPORT
void
OS_PASCAL
DTLfree(
#ifdef use_prototypes
char *ptr
#endif
);

/* If your SIT application does use threading, we recommend you call 
   DTLinit(???) before calling any other DTL function to allow for 
   as many threads as you may use */
extern
DTL_EXPORT
Boolean
OS_PASCAL
DTLinit(
#ifdef use_prototypes
int allowedNumberOfThreads
#endif
);

extern
DTL_EXPORT
int
OS_PASCAL
DTLreloadBookStyleSheets(
#ifdef use_prototypes
DtlBookId bid
#endif
);

enum {
   DTL__PERSISTENCE_NEW_BOOK,
   DTL__PERSISTENCE_RESTART,
   DTL__PERSISTENCE_EDIT
};



#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* DTL_HEADER */
